@@ -30,24 +30,30 @@ class TestCharacter(TestCommons, unittest.TestCase):
     def test_character_from_content(self):
         """Testing parsing a character's HTML content"""
         character = Character.from_content(self.load_resource(FILE_CHARACTER_RESOURCE))
-        self._compare_character(Character("Tschas", "Gladera", Vocation.DRUID, 260, Sex.FEMALE), character)
+        self._compare_character(Character("Tschas", "Gladera", Vocation.ELDER_DRUID, 522, Sex.FEMALE), character)
         self.assertIsNotNone(character.guild_membership)
-        self.assertEqual("Atlantis", character.guild_membership.name)
-        self.assertEqual("Gaia", character.guild_membership.rank)
+        self.assertEqual("Bald Dwarfs", character.guild_membership.name)
+        self.assertEqual("Emperor", character.guild_membership.rank)
         self.assertIsNotNone(character.guild_url)
         self.assertIsNone(character.married_to_url)
         self.assertEqual(character.guild_name, character.guild_membership.name)
         self.assertEqual(character.guild_rank, character.guild_membership.rank)
-        self.assertEqual(AccountStatus.FREE_ACCOUNT, character.account_status)
-        self.assertEqual(182, character.achievement_points)
+        self.assertEqual(AccountStatus.PREMIUM_ACCOUNT, character.account_status)
+        self.assertEqual(304, character.achievement_points)
         self.assertIsNone(character.deletion_date)
         self.assertIsNotNone(character.deaths)
-        self.assertEqual(0, character.deaths.__len__())
-        self.assertEqual(parse_tibia_datetime("Aug 04 2019, 13:56:59 CEST"), character.last_login)
+        self.assertEqual(2, character.deaths.__len__())
+        self.assertEqual(parse_tibia_datetime("Aug 02 2021, 17:32:07 CEST"), character.last_login)
         self.assertEqual(character.url, Character.get_url(character.name))
         self.assertEqual(5, len(character.other_characters))
         self.assertFalse(character.hidden)
 
+        # Badges
+        self.assertEqual(3, len(character.account_badges))
+        badge = character.account_badges[0]
+        self.assertEqual("Ancient Hero", badge.name)
+        self.assertEqual("The account is older than 15 years.", badge.description)
+
     def test_character_from_content_not_found(self):
         """Testing parsing a character not found page"""
         content = self.load_resource(FILE_CHARACTER_NOT_FOUND)
@@ -95,11 +101,28 @@ class TestCharacter(TestCommons, unittest.TestCase):
         """Testing parsing a character with complex deaths (summons, assists, etc)"""
         content = self.load_resource(FILE_CHARACTER_DEATHS_COMPLEX)
         char = Character.from_content(content)
-        self.assertTrue(char.deaths)
-        self.assertIsInstance(char.deaths[0], Death)
-        self.assertEqual(len(char.deaths), 19)
-        oldest_death = char.deaths[-1]
-        self.assertEqual(oldest_death.killer.summon, "a fire elemental")
+        self.assertEqual(5, len(char.deaths))
+        death1, death2, death3, death4, death5 = char.deaths
+        self.assertIsInstance(death1, Death)
+        self.assertEqual(23, len(death1.killers))
+        self.assertEqual(1, len(death1.assists))
+
+        self.assertIsInstance(death2, Death)
+        self.assertEqual(1, len(death2.killers))
+        self.assertEqual(0, len(death2.assists))
+
+        self.assertIsInstance(death3, Death)
+        self.assertEqual(11, len(death3.killers))
+        self.assertEqual(0, len(death3.assists))
+        self.assertEqual("a paladin familiar", death3.killers[-1].summon)
+        self.assertEqual("Alloy Hat", death3.killers[-1].name)
+        self.assertTrue(death3.killers[-1].traded)
+
+        self.assertIsInstance(death4, Death)
+        self.assertEqual(12, len(death4.killers))
+        self.assertEqual(0, len(death4.assists))
+        self.assertEqual("Cliff Lee Burton", death4.killers[-1].name)
+        self.assertTrue(death4.killers[-1].traded)
 
     def test_character_from_content_badges_and_title(self):
         """Testing parsing a character with account badges and a title"""
